==> huaweicloudsdkmrs-3.0.82-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/show_job_exe_list_new_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowJobExeListNewResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_list': 'list[JobQueryBean]'
    }

    attribute_map = {
        'job_list': 'job_list'
    }

    def __init__(self, job_list=None):
        """ShowJobExeListNewResponse - a model defined in huaweicloud sdk"""
        
        super(ShowJobExeListNewResponse, self).__init__()

        self._job_list = None
        self.discriminator = None

        if job_list is not None:
            self.job_list = job_list

    @property
    def job_list(self):
        """Gets the job_list of this ShowJobExeListNewResponse.

        作业列表。

        :return: The job_list of this ShowJobExeListNewResponse.
        :rtype: list[JobQueryBean]
        """
        return self._job_list

    @job_list.setter
    def job_list(self, job_list):
        """Sets the job_list of this ShowJobExeListNewResponse.

        作业列表。

        :param job_list: The job_list of this ShowJobExeListNewResponse.
        :type: list[JobQueryBean]
        """
        self._job_list = job_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowJobExeListNewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmrs-3.0.100-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/show_job_exe_list_new_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowJobExeListNewResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_list': 'list[JobQueryBean]'
    }

    attribute_map = {
        'job_list': 'job_list'
    }

    def __init__(self, job_list=None):
        """ShowJobExeListNewResponse

        The model defined in huaweicloud sdk

        :param job_list: 作业列表。
        :type job_list: list[:class:`huaweicloudsdkmrs.v2.JobQueryBean`]
        """
        
        super(ShowJobExeListNewResponse, self).__init__()

        self._job_list = None
        self.discriminator = None

        if job_list is not None:
            self.job_list = job_list

    @property
    def job_list(self):
        """Gets the job_list of this ShowJobExeListNewResponse.

        作业列表。

        :return: The job_list of this ShowJobExeListNewResponse.
        :rtype: list[:class:`huaweicloudsdkmrs.v2.JobQueryBean`]
        """
        return self._job_list

    @job_list.setter
    def job_list(self, job_list):
        """Sets the job_list of this ShowJobExeListNewResponse.

        作业列表。

        :param job_list: The job_list of this ShowJobExeListNewResponse.
        :type job_list: list[:class:`huaweicloudsdkmrs.v2.JobQueryBean`]
        """
        self._job_list = job_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowJobExeListNewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
